Content-Length: 3018 | pFad | http://github.com/google/oss-fuzz/pull/11677.patch
67882379
From ba116825ee15d571a46a18abc59f9a850455e1e1 Mon Sep 17 00:00:00 2001
From: Justin Dhillon
Date: Thu, 7 Mar 2024 21:41:39 -0800
Subject: [PATCH] upgrade to Go 1.22
---
infra/base-images/base-builder/install_go.sh | 4 ++--
projects/cryptofuzz/Dockerfile | 1 +
projects/cryptofuzz/build.sh | 15 +++++++++++++--
3 files changed, 16 insertions(+), 4 deletions(-)
diff --git a/infra/base-images/base-builder/install_go.sh b/infra/base-images/base-builder/install_go.sh
index e6b1b3720c52..1591a53ebce0 100755
--- a/infra/base-images/base-builder/install_go.sh
+++ b/infra/base-images/base-builder/install_go.sh
@@ -16,9 +16,9 @@
################################################################################
cd /tmp
-wget https://go.dev/dl/go1.21.0.linux-amd64.tar.gz
+wget https://go.dev/dl/go1.22.1.linux-amd64.tar.gz
mkdir temp-go
-tar -C temp-go/ -xzf go1.21.0.linux-amd64.tar.gz
+tar -C temp-go/ -xzf go1.22.1.linux-amd64.tar.gz
mkdir /root/.go/
mv temp-go/go/* /root/.go/
rm -rf temp-go
diff --git a/projects/cryptofuzz/Dockerfile b/projects/cryptofuzz/Dockerfile
index 3d058de305a0..e2c67e7ea81f 100644
--- a/projects/cryptofuzz/Dockerfile
+++ b/projects/cryptofuzz/Dockerfile
@@ -25,6 +25,7 @@ RUN pip3 install 'pip>=20'
RUN wget https://go.dev/dl/go1.20.10.linux-amd64.tar.gz
RUN wget https://go.dev/dl/go1.21.3.linux-amd64.tar.gz
+RUN wget https://go.dev/dl/go1.22.1.linux-amd64.tar.gz
RUN git clone --depth 1 https://github.com/golang/go go-dev
RUN git clone --depth 1 https://github.com/golang/crypto go-crypto
RUN git clone --depth 1 https://github.com/golang/sys.git go-sys
diff --git a/projects/cryptofuzz/build.sh b/projects/cryptofuzz/build.sh
index 310cd9c27cf2..cadab4a8debf 100755
--- a/projects/cryptofuzz/build.sh
+++ b/projects/cryptofuzz/build.sh
@@ -25,6 +25,17 @@ export GO111MODULE=off
mkdir $SRC/go-bootstrap
cd $SRC/go-bootstrap
+tar zxf $SRC/go1.22.1.linux-amd64.tar.gz
+mv go/ go-122
+export GOROOT_122=$SRC/go-bootstrap/go-122/
+export GOPATH_122=$GOROOT_122/packages/
+mkdir $GOPATH_122
+mkdir -p $GOPATH_122/src/golang.org/x/crypto/
+cp -R $SRC/go-crypto/* $GOPATH_122/src/golang.org/x/crypto/
+mkdir -p $GOPATH_122/src/golang.org/x/sys/
+cp -R $SRC/go-sys/* $GOPATH_122/src/golang.org/x/sys/
+export PATH_GO_121=$GOROOT_122/bin:$GOROOT_122/packages/bin:$PATH
+
tar zxf $SRC/go1.21.3.linux-amd64.tar.gz
mv go/ go-121
export GOROOT_121=$SRC/go-bootstrap/go-121/
@@ -511,11 +522,11 @@ cd $SRC/cryptofuzz/modules/monero
make -B
##############################################################################
# Compile Cryptofuzz Golang (121) module
if [[ $CFLAGS != *sanitize=memory* && $CFLAGS != *-m32* ]]
then
cd $SRC/cryptofuzz/modules/golang
- GOROOT="$GOROOT_121" GOPATH="$GOPATH_121" PATH="$PATH_GO_121" make -B
+ GOROOT="$GOROOT_122" GOPATH="$GOPATH_122" PATH="$PATH_GO_122" make -B
fi
if [[ $CFLAGS != *-m32* ]]
--- a PPN by Garber Painting Akron. With Image Size Reduction included!Fetched URL: http://github.com/google/oss-fuzz/pull/11677.patch
Alternative Proxies:
Alternative Proxy
pFad Proxy
@@ -511,11 +522,11 @@ cd $SRC/cryptofuzz/modules/monero
make -B
##############################################################################
-# Compile Cryptofuzz Golang (121) module
+# Compile Cryptofuzz Golang (122) module
if [[ $CFLAGS != *sanitize=memory* && $CFLAGS != *-m32* ]]
then
pFad v3 Proxy
pFad v4 Proxy